
Installation
============


To install the latest stable release via pip, run:

.. code-block:: bash

    $ pip install Flask-Plugin


Alternatively with easy_install, run:

.. code-block:: bash

    $ easy_install Flask-Plugin


To install the bleeding-edge version of the project:

.. code-block:: bash

    $ git clone http://github.com/bprinty/Flask-Plugin.git
    $ cd Flask-Plugin
    $ python setup.py install
